@@ -3,11 +3,15 @@ if(require("testthat", quietly = TRUE)) {
     require(pkg, character.only=TRUE, quietly=TRUE)
     if(getRversion() < "3.5.0") { withAutoprint <- identity ; prt <- print } else { prt <- identity }
     if(Sys.getenv("USER") %in% c("maechler", "bbolker")) withAutoprint({
-        ## for developers', notably MM's sake:
-        cat(".libPaths():\n"); prt(lP <- .libPaths())
-        cat("entries in .libPaths()[1] :\n"); prt(list.files(lP[1], include.dirs=TRUE))
+        ## for developers' sake:
+        lP <- .libPaths() # ---- .libPaths() : ----
+        prt(lP)
+        ## ---- Entries in .libPaths()[1] : ----
+        prt(list.files(lP[1], include.dirs=TRUE))
         prt(sessionInfo())
         prt(packageDescription("Matrix"))
+        ## 'lme4' from packageDescription "file" :
+        prt(attr(packageDescription("lme4"), "file"))
     })
     test_check(pkg)
     ##======== ^^^
