@@ -1,5 +1,4 @@
 library(lme4)
-(testLevel <- if (nzchar(s <- Sys.getenv("LME4_TEST_LEVEL"))) as.numeric(s) else 1)
 
  ## setup
  ## library(polytomous)
@@ -26,6 +25,7 @@ if (FALSE) {
     ## Error in pp$updateDecomp() : Downdated VtV is not positive definite
 }
 
+(testLevel <- lme4:::testLevel())
 if (testLevel > 2) {
     glmer(formula.poisson,data=data.poisson,family=poisson,
           control=glmerControl(compDev=FALSE),optimizer="bobyqa")
